@@ -882,4 +882,6 @@ GRANT SELECT ON orders TO ROLE PUBLIC
 GRANT SELECT ON nation TO alice WITH GRANT OPTION
 GRANT DELETE ON SCHEMA finance TO bob
 SELECT attach
-SELECT detach
\ No newline at end of file
+SELECT detach
+SELECT 1 OFFSET 1
+SELECT 1 LIMIT 1
